@@ -1,6 +1,5 @@
 import os
 import pytest
-import shutil
 
 from ansible_runner import defaults
 from ansible_runner.interface import run, run_async, run_command, run_command_async, get_plugin_docs, \
@@ -12,22 +11,21 @@ def test_run():
     assert r.status == 'successful'
 
 
-def test_run_async():
-    thread, r = run_async(module='debug', host_pattern='localhost')
-    thread.join()
+@pytest.mark.parametrize(
+    'playbook', (
+        [{'hosts': 'localhost', 'tasks': [{'ping': ''}]}],
+        {'hosts': 'localhost', 'tasks': [{'ping': ''}]},
+    )
+)
+def test_run_playbook_data(playbook, tmp_path):
+    r = run(private_data_dir=str(tmp_path), playbook=playbook)
     assert r.status == 'successful'
 
 
-@pytest.fixture
-def printenv_example(test_data_dir):
-    private_data_dir = os.path.join(test_data_dir, 'printenv')
-    # TODO: remove if main code can handle this for us
-    # https://github.com/ansible/ansible-runner/issues/493
-    # for now, necessary to prevent errors on re-run
-    env_dir = os.path.join(private_data_dir, 'env')
-    if os.path.exists(env_dir):
-        shutil.rmtree(env_dir)
-    return private_data_dir
+def test_run_async(tmp_path):
+    thread, r = run_async(private_data_dir=str(tmp_path), module='debug', host_pattern='localhost')
+    thread.join()
+    assert r.status == 'successful'
 
 
 def get_env_data(res):
@@ -45,9 +43,16 @@ def get_env_data(res):
         raise RuntimeError('Count not find look_at_environment task from playbook')
 
 
-def test_env_accuracy(request, printenv_example):
+def test_env_accuracy(request, project_fixtures):
+    printenv_example = project_fixtures / 'printenv'
     os.environ['SET_BEFORE_TEST'] = 'MADE_UP_VALUE'
 
+    # Remove the envvars file if it exists
+    try:
+        os.remove(printenv_example / "env/envvars")
+    except FileNotFoundError:
+        pass
+
     def remove_test_env_var():
         if 'SET_BEFORE_TEST' in os.environ:
             del os.environ['SET_BEFORE_TEST']
@@ -66,9 +71,35 @@ def test_env_accuracy(request, printenv_example):
 
     assert actual_env == res.config.env
 
+    # Assert that the env file was properly created
+    assert os.path.exists(printenv_example / "env/envvars") == 1
 
-@pytest.mark.serial
-def test_env_accuracy_inside_container(request, printenv_example, container_runtime_installed):
+
+def test_no_env_files(request, project_fixtures):
+    printenv_example = project_fixtures / 'printenv'
+    os.environ['SET_BEFORE_TEST'] = 'MADE_UP_VALUE'
+
+    # Remove the envvars file if it exists
+    try:
+        os.remove(printenv_example / "env/envvars")
+    except FileNotFoundError:
+        pass
+
+    res = run(
+        private_data_dir=printenv_example,
+        playbook='get_environment.yml',
+        inventory=None,
+        envvars={'FROM_TEST': 'FOOBAR'},
+        suppress_env_files=True,
+    )
+    assert res.rc == 0, res.stdout.read()
+    # Assert that the env file was not created
+    assert os.path.exists(printenv_example / "env/envvars") == 0
+
+
+@pytest.mark.test_all_runtimes
+def test_env_accuracy_inside_container(request, project_fixtures, runtime):
+    printenv_example = project_fixtures / 'printenv'
     os.environ['SET_BEFORE_TEST'] = 'MADE_UP_VALUE'
 
     def remove_test_env_var():
@@ -84,7 +115,7 @@ def test_env_accuracy_inside_container(request, printenv_example, container_runt
         inventory=None,
         envvars={'FROM_TEST': 'FOOBAR'},
         settings={
-            'process_isolation_executable': container_runtime_installed,
+            'process_isolation_executable': runtime,
             'process_isolation': True
         }
     )
@@ -104,8 +135,8 @@ def test_env_accuracy_inside_container(request, printenv_example, container_runt
     assert env_data['cwd'] == res.config.cwd
 
 
-def test_multiple_inventories(test_data_dir):
-    private_data_dir = os.path.join(test_data_dir, 'debug')
+def test_multiple_inventories(project_fixtures):
+    private_data_dir = project_fixtures / 'debug'
 
     res = run(
         private_data_dir=private_data_dir,
@@ -120,14 +151,14 @@ def test_multiple_inventories(test_data_dir):
     assert 'host_2' in stdout
 
 
-def test_inventory_absolute_path(test_data_dir):
-    private_data_dir = os.path.join(test_data_dir, 'debug')
+def test_inventory_absolute_path(project_fixtures):
+    private_data_dir = project_fixtures / 'debug'
 
     res = run(
         private_data_dir=private_data_dir,
         playbook='debug.yml',
         inventory=[
-            os.path.join(private_data_dir, 'inventory', 'inv_1'),
+            str(private_data_dir / 'inventory' / 'inv_1'),
         ],
     )
     stdout = res.stdout.read()
@@ -138,33 +169,58 @@ def test_inventory_absolute_path(test_data_dir):
     assert 'host_2' not in stdout
 
 
-def test_run_command(test_data_dir):
-    private_data_dir = os.path.join(test_data_dir, 'debug')
-    inventory = os.path.join(private_data_dir, 'inventory', 'inv_1')
-    playbook = os.path.join(private_data_dir, 'project', 'debug.yml')
+def test_run_command(project_fixtures):
+    private_data_dir = project_fixtures / 'debug'
+    inventory = private_data_dir / 'inventory' / 'inv_1'
+    playbook = private_data_dir / 'project' / 'debug.yml'
     out, err, rc = run_command(
         private_data_dir=private_data_dir,
         executable_cmd='ansible-playbook',
-        cmdline_args=[playbook, '-i', inventory]
+        cmdline_args=[str(playbook), '-i', str(inventory)]
     )
     assert "Hello world!" in out
     assert rc == 0
     assert err == ''
 
 
-def test_run_ansible_command_within_container(test_data_dir, container_runtime_installed):
-    private_data_dir = os.path.join(test_data_dir, 'debug')
-    inventory = os.path.join(private_data_dir, 'inventory', 'inv_1')
-    playbook = os.path.join(private_data_dir, 'project', 'debug.yml')
+def test_run_command_injection_error():
+    out, err, rc = run_command(
+        executable_cmd='whoami',
+        cmdline_args=[';hostname'],
+        runner_mode='subprocess',
+    )
+    assert rc == 1
+    assert "usage: whoami" in err or "whoami: extra operand ‘;hostname’" in err
+
+
+@pytest.mark.test_all_runtimes
+def test_run_command_injection_error_within_container(runtime):
+    out, err, rc = run_command(
+        executable_cmd='whoami',
+        cmdline_args=[';hostname'],
+        runner_mode='subprocess',
+        process_isolation_executable=runtime,
+        process_isolation=True,
+        container_image=defaults.default_container_image,
+    )
+    assert rc == 1
+    assert "whoami: extra operand ';hostname'" in err
+
+
+@pytest.mark.test_all_runtimes
+def test_run_ansible_command_within_container(project_fixtures, runtime):
+    private_data_dir = project_fixtures / 'debug'
+    inventory = private_data_dir / 'inventory' / 'inv_1'
+    playbook = private_data_dir / 'project' / 'debug.yml'
     container_kwargs = {
-        'process_isolation_executable': container_runtime_installed,
+        'process_isolation_executable': runtime,
         'process_isolation': True,
         'container_image': defaults.default_container_image
     }
     out, err, rc = run_command(
         private_data_dir=private_data_dir,
         executable_cmd='ansible-playbook',
-        cmdline_args=[playbook, '-i', inventory],
+        cmdline_args=[str(playbook), '-i', str(inventory)],
         **container_kwargs
     )
     assert "Hello world!" in out
@@ -172,12 +228,13 @@ def test_run_ansible_command_within_container(test_data_dir, container_runtime_i
     assert err == ''
 
 
-def test_run_script_within_container(test_data_dir, container_runtime_installed):
-    private_data_dir = os.path.join(test_data_dir, 'debug')
-    script_path = os.path.join(test_data_dir, 'files')
+@pytest.mark.test_all_runtimes
+def test_run_script_within_container(project_fixtures, runtime):
+    private_data_dir = project_fixtures / 'debug'
+    script_path = project_fixtures / 'files'
     container_volume_mounts = ["{}:{}:Z".format(script_path, script_path)]
     container_kwargs = {
-        'process_isolation_executable': container_runtime_installed,
+        'process_isolation_executable': runtime,
         'process_isolation': True,
         'container_image': defaults.default_container_image,
         'container_volume_mounts': container_volume_mounts
@@ -185,7 +242,7 @@ def test_run_script_within_container(test_data_dir, container_runtime_installed)
     out, _, rc = run_command(
         private_data_dir=private_data_dir,
         executable_cmd='python3',
-        cmdline_args=[os.path.join(script_path, 'test_ee.py')],
+        cmdline_args=[str(script_path / 'test_ee.py')],
         **container_kwargs
     )
 
@@ -193,14 +250,14 @@ def test_run_script_within_container(test_data_dir, container_runtime_installed)
     assert rc == 0
 
 
-def test_run_command_async(test_data_dir):
-    private_data_dir = os.path.join(test_data_dir, 'debug')
-    inventory = os.path.join(private_data_dir, 'inventory', 'inv_1')
-    playbook = os.path.join(private_data_dir, 'project', 'debug.yml')
+def test_run_command_async(project_fixtures):
+    private_data_dir = project_fixtures / 'debug'
+    inventory = private_data_dir / 'inventory' / 'inv_1'
+    playbook = private_data_dir / 'project' / 'debug.yml'
     thread, r = run_command_async(
         private_data_dir=private_data_dir,
         executable_cmd='ansible-playbook',
-        cmdline_args=[playbook, '-i', inventory]
+        cmdline_args=[str(playbook), '-i', str(inventory)]
     )
     thread.join()
     out = r.stdout.read()
@@ -231,9 +288,10 @@ def test_get_plugin_docs_async():
     assert r.status == 'successful'
 
 
-def test_get_plugin_docs_within_container(container_runtime_installed):
+@pytest.mark.test_all_runtimes
+def test_get_plugin_docs_within_container(runtime):
     container_kwargs = {
-        'process_isolation_executable': container_runtime_installed,
+        'process_isolation_executable': runtime,
         'process_isolation': True,
         'container_image': defaults.default_container_image
     }
@@ -256,9 +314,10 @@ def test_get_plugin_docs_list():
     assert 'file' in out
 
 
-def test_get_plugin_docs_list_within_container(container_runtime_installed):
+@pytest.mark.test_all_runtimes
+def test_get_plugin_docs_list_within_container(runtime):
     container_kwargs = {
-        'process_isolation_executable': container_runtime_installed,
+        'process_isolation_executable': runtime,
         'process_isolation': True,
         'container_image': defaults.default_container_image
     }
@@ -279,14 +338,14 @@ def test_ansible_config():
     assert 'DEFAULT_VERBOSITY' in out
 
 
-def test_get_inventory(test_data_dir):
-    private_data_dir = os.path.join(test_data_dir, 'debug')
-    inventory1 = os.path.join(private_data_dir, 'inventory', 'inv_1')
-    inventory2 = os.path.join(private_data_dir, 'inventory', 'inv_2')
+def test_get_inventory(project_fixtures):
+    private_data_dir = project_fixtures / 'debug'
+    inventory1 = private_data_dir / 'inventory' / 'inv_1'
+    inventory2 = private_data_dir / 'inventory' / 'inv_2'
 
     out, _ = get_inventory(
         action='list',
-        inventories=[inventory1, inventory2],
+        inventories=[str(inventory1), str(inventory2)],
         response_format='json',
         quiet=True
     )
@@ -294,22 +353,36 @@ def test_get_inventory(test_data_dir):
     assert 'host_2' in out['ungrouped']['hosts']
 
 
-def test_get_inventory_within_container(test_data_dir, container_runtime_installed):
+@pytest.mark.test_all_runtimes
+def test_get_inventory_within_container(project_fixtures, runtime):
     container_kwargs = {
-        'process_isolation_executable': container_runtime_installed,
+        'process_isolation_executable': runtime,
         'process_isolation': True,
         'container_image': defaults.default_container_image
     }
-    private_data_dir = os.path.join(test_data_dir, 'debug')
-    inventory1 = os.path.join(private_data_dir, 'inventory', 'inv_1')
-    inventory2 = os.path.join(private_data_dir, 'inventory', 'inv_2')
+    private_data_dir = project_fixtures / 'debug'
+    inventory1 = private_data_dir / 'inventory' / 'inv_1'
+    inventory2 = private_data_dir / 'inventory' / 'inv_2'
 
     out, _ = get_inventory(
         action='list',
-        inventories=[inventory1, inventory2],
+        inventories=[str(inventory1), str(inventory2)],
         response_format='json',
         quiet=True,
         **container_kwargs
     )
     assert 'host_1' in out['ungrouped']['hosts']
     assert 'host_2' in out['ungrouped']['hosts']
+
+
+def test_run_role(project_fixtures):
+    ''' Test that we can run a role via the API. '''
+    private_data_dir = project_fixtures / 'debug'
+
+    res = run(
+        private_data_dir=private_data_dir,
+        role='hello_world',
+    )
+    stdout = res.stdout.read()
+    assert res.rc == 0, stdout
+    assert 'Hello World!' in stdout
