@@ -72,7 +72,7 @@ def test_base_config_project_dir(tmp_path):
     assert rc.project_dir == tmp_path.joinpath('project').as_posix()
 
 
-def test_prepare_environment_vars_only_strings(mocker):
+def test_prepare_environment_vars_only_strings_from_file(mocker):
     rc = BaseConfig(envvars=dict(D='D'))
 
     value = dict(A=1, B=True, C="foo")
@@ -91,6 +91,20 @@ def test_prepare_environment_vars_only_strings(mocker):
     assert rc.env['D'] == 'D'
 
 
+def test_prepare_environment_vars_only_strings_from_interface():
+    rc = BaseConfig(envvars=dict(D='D', A=1, B=True, C="foo"))
+    rc._prepare_env()
+
+    assert 'A' in rc.env
+    assert isinstance(rc.env['A'], six.string_types)
+    assert 'B' in rc.env
+    assert isinstance(rc.env['B'], six.string_types)
+    assert 'C' in rc.env
+    assert isinstance(rc.env['C'], six.string_types)
+    assert 'D' in rc.env
+    assert rc.env['D'] == 'D'
+
+
 def test_prepare_environment_pexpect_defaults():
     rc = BaseConfig()
     rc._prepare_env()
@@ -223,32 +237,35 @@ def test_prepare_with_ssh_key(mocker, tmp_path):
 
 
 def test_wrap_args_with_ssh_agent_defaults(tmp_path):
-    rc = BaseConfig(private_data_dir=str(tmp_path))
-    res = rc.wrap_args_with_ssh_agent(['ansible-playbook', 'main.yaml'], f'{tmp_path}/sshkey')
+    tp = tmp_path.as_posix()
+    rc = BaseConfig(private_data_dir=tp)
+    res = rc.wrap_args_with_ssh_agent(['ansible-playbook', 'main.yaml'], f'{tp}/sshkey')
     assert res == [
         'ssh-agent',
         'sh', '-c',
-        f"trap 'rm -f {tmp_path}/sshkey' EXIT && ssh-add {tmp_path}/sshkey && rm -f {tmp_path}/sshkey && ansible-playbook main.yaml"
+        f"trap 'rm -f {tp}/sshkey' EXIT && ssh-add {tp}/sshkey && rm -f {tp}/sshkey && ansible-playbook main.yaml"
     ]
 
 
 def test_wrap_args_with_ssh_agent_with_auth(tmp_path):
-    rc = BaseConfig(private_data_dir=str(tmp_path))
-    res = rc.wrap_args_with_ssh_agent(['ansible-playbook', 'main.yaml'], f'{tmp_path}/sshkey', f'{tmp_path}/sshauth')
+    tp = tmp_path.as_posix()
+    rc = BaseConfig(private_data_dir=tp)
+    res = rc.wrap_args_with_ssh_agent(['ansible-playbook', 'main.yaml'], f'{tp}/sshkey', f'{tp}/sshauth')
     assert res == [
-        'ssh-agent', '-a', f'{tmp_path}/sshauth',
+        'ssh-agent', '-a', f'{tp}/sshauth',
         'sh', '-c',
-        f"trap 'rm -f {tmp_path}/sshkey' EXIT && ssh-add {tmp_path}/sshkey && rm -f {tmp_path}/sshkey && ansible-playbook main.yaml"
+        f"trap 'rm -f {tp}/sshkey' EXIT && ssh-add {tp}/sshkey && rm -f {tp}/sshkey && ansible-playbook main.yaml"
     ]
 
 
 def test_wrap_args_with_ssh_agent_silent(tmp_path):
-    rc = BaseConfig(private_data_dir=str(tmp_path))
-    res = rc.wrap_args_with_ssh_agent(['ansible-playbook', 'main.yaml'], f'{tmp_path}/sshkey', silence_ssh_add=True)
+    tp = tmp_path.as_posix()
+    rc = BaseConfig(private_data_dir=tp)
+    res = rc.wrap_args_with_ssh_agent(['ansible-playbook', 'main.yaml'], f'{tp}/sshkey', silence_ssh_add=True)
     assert res == [
         'ssh-agent',
         'sh', '-c',
-        f"trap 'rm -f {tmp_path}/sshkey' EXIT && ssh-add {tmp_path}/sshkey 2>/dev/null && rm -f {tmp_path}/sshkey && ansible-playbook main.yaml"
+        f"trap 'rm -f {tp}/sshkey' EXIT && ssh-add {tp}/sshkey 2>/dev/null && rm -f {tp}/sshkey && ansible-playbook main.yaml"
     ]
 
 
